from example.schema import TestSchema
from schemazer.commons.errors import RequestErrors
from tests.base import BaseTestCase


class TestSystemParameters(BaseTestCase):
    def test_get_method_system_parameter_from_query(self):
        response = self.get(
            f'/systems.withRequiredParameter?token={self.token}')
        assert response.status_code == 200
        assert response.json['systems']['token'] == self.token

    def test_post_method_system_parameter_from_query(self):
        response = self.post(
            '/systems.withRequiredParameter',
            {'token': self.token})
        assert response.status_code == 200
        assert response.json['systems']['token'] == self.token

    def test_get_method_system_parameter_from_header(self):
        response = self.get(
            f'/systems.withRequiredParameter',
            headers={'Auth-Token': self.token}
        )
        assert response.status_code == 200
        assert response.json['systems']['token'] == self.token

    def test_post_method_system_parameter_from_header(self):
        response = self.post(
            '/systems.withRequiredParameter',
            {},
            headers={'Auth-Token': self.token})
        assert response.status_code == 200
        assert response.json['systems']['token'] == self.token

    def test_get_method_system_parameter_from_cookie(self):
        self.client.set_cookie('localhost', 'auth_token', self.token)
        response = self.get(
            f'/systems.withRequiredParameter')
        assert response.status_code == 200
        assert response.json['systems']['token'] == self.token

    def test_post_method_system_parameter_from_cookie(self):
        self.client.set_cookie('localhost', 'auth_token', self.token)
        response = self.post(
            '/systems.withRequiredParameter',
            {})
        assert response.status_code == 200
        assert response.json['systems']['token'] == self.token

    def test_post_method_missing_required_system_parameter(self):
        response = self.post(
            '/systems.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'token'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code

    def test_get_method_missing_required_system_parameter(self):
        response = self.get(
            '/systems.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'token'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code

    def test_get_method_default_system_parameter(self):
        response = self.get(
            '/systems.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['systems']['token'] ==
                TestSchema.systems.withRequiredAndDefaultParameter.systems[
                    0].default)

    def test_post_method_default_system_parameter(self):
        response = self.post(
            '/systems.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['systems']['token'] ==
                TestSchema.systems.withRequiredAndDefaultParameter.systems[
                    0].default)



from example.schema import TestSchema
from schemazer.commons.errors import RequestErrors
from tests.base import BaseTestCase


class TestCookies(BaseTestCase):
    def test_get_method_with_required_cookie(self):
        self.client.set_cookie('localhost', 'apikey', self.apikey)
        response = self.get(
            f'/cookies.withRequiredParameter')
        assert response.status_code == 200
        assert response.json['cookies']['apikey'] == self.apikey

    def test_post_method_with_required_cookie(self):
        self.client.set_cookie('localhost', 'apikey', self.apikey)
        response = self.post(
            '/cookies.withRequiredParameter')
        assert response.status_code == 200
        assert response.json['cookies']['apikey'] == self.apikey

    def test_get_method_with_required_and_default_cookie(self):
        response = self.get(
            '/cookies.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['cookies']['apikey'] ==
                TestSchema.cookies.withRequiredAndDefaultParameter.cookies[
                    0].default)

    def test_post_method_with_required_and_default_cookie(self):
        response = self.post(
            '/cookies.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['cookies']['apikey'] ==
                TestSchema.cookies.withRequiredAndDefaultParameter.cookies[
                    0].default)

    def test_post_method_missing_required_cookie(self):
        response = self.post(
            '/cookies.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'apikey'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code

    def test_get_method_missing_required_cookie(self):
        response = self.get(
            '/cookies.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'apikey'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code



import unittest

from commons.errors import RequestErrors
from example.schema import TestSchema
from tests.base import BaseTestCase


class TestQueryArgs(BaseTestCase):
    def test_get_method_with_required_parameter(self):
        response = self.get(
            f'/args.withRequiredParameter?email={self.email}')
        assert response.status_code == 200
        assert response.json['args']['email'] == self.email

    def test_post_method_with_required_parameter(self):
        response = self.post(
            '/args.withRequiredParameter',
            {'email': self.email})
        assert response.status_code == 200
        assert response.json['args']['email'] == self.email

    def test_get_method_with_required_and_default_parameter(self):
        response = self.get(
            '/args.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['args']['email'] ==
                TestSchema.args.withRequiredAndDefaultParameter.parameters[
                    0].default)

    def test_post_method_with_required_and_default_parameter(self):
        response = self.post(
            '/args.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['args']['email'] ==
                TestSchema.args.withRequiredAndDefaultParameter.parameters[
                    0].default)

    def test_post_method_missing_required_parameter(self):
        response = self.post(
            '/args.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'email'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code

    def test_get_method_missing_required_parameter(self):
        response = self.get(
            '/args.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'email'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code

    def test_post_method_args_to_type_converter(self):
        int_as_string = '123'
        response = self.post(
            '/args.withRequiredAndDefaultParameter',
            {'int': int_as_string}
        )
        assert response.status_code == 200
        assert 'args' in response.json
        assert 'int' in response.json['args']
        assert response.json['args']['int'] == int(int_as_string)

    def test_get_method_args_to_type_converter(self):
        int_as_string = '123'
        response = self.get(
            '/args.withRequiredAndDefaultParameter?int=123'
        )
        assert response.status_code == 200
        assert 'args' in response.json
        assert 'int' in response.json['args']
        assert response.json['args']['int'] == int(int_as_string)


if __name__ == '__main__':
    unittest.main()



import unittest

from example.app import create_app
from example.schema import TestSchema
from schemazer import RequestValidator


class BaseTestCase(unittest.TestCase):

    def setUp(self):
        self.validator = RequestValidator()
        self.schema = TestSchema()
        self.app = create_app()
        self.client = self.app.test_client()

        self.email = 'example@mail.ru'
        self.apikey = 'da0fbb5f-f453-40d0-9975-07f8daf3aa43'
        self.token = '070fbb5f-f453-40d0-9975-07f8daf3aa43'

    def post(self, url, data=None, **kwargs):
        return self.client.post(url, json=data or {}, **kwargs)

    def get(self, url, **kwargs):
        return self.client.get(url, **kwargs)



from example.schema import TestSchema
from schemazer.commons.errors import RequestErrors
from tests.base import BaseTestCase


class TestHeaders(BaseTestCase):
    def test_get_method_with_required_header(self):
        response = self.get(
            f'/headers.withRequiredParameter',
            headers={'Apikey': self.apikey})
        assert response.status_code == 200
        assert response.json['headers']['Apikey'] == self.apikey

    def test_post_method_with_required_header(self):
        response = self.post(
            '/headers.withRequiredParameter',
            headers={'Apikey': self.apikey})
        assert response.status_code == 200
        assert response.json['headers']['Apikey'] == self.apikey

    def test_get_method_with_required_and_default_header(self):
        response = self.get(
            '/headers.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['headers']['Apikey'] ==
                TestSchema.headers.withRequiredAndDefaultParameter.headers[
                    0].default)

    def test_post_method_with_required_and_default_header(self):
        response = self.post(
            '/headers.withRequiredAndDefaultParameter')
        assert response.status_code == 200
        assert (response.json['headers']['Apikey'] ==
                TestSchema.headers.withRequiredAndDefaultParameter.headers[
                    0].default)

    def test_post_method_missing_required_header(self):
        response = self.post(
            '/headers.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'Apikey'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code

    def test_get_method_missing_required_header(self):
        response = self.get(
            '/headers.withRequiredParameter')
        assert response.status_code == 200
        assert 'error' in response.json
        assert response.json['error']['failure_param'] == 'Apikey'
        assert response.json['error']['code'] == RequestErrors.BadRequest.code
